@@ -35,7 +35,7 @@ def require(appname):
 
 
 class WorkerRequest(object):
-    
+    timeout = None
     def response(self):
         return self
     
@@ -74,7 +74,6 @@ def make_response(request, response, err = None):
     return response
 
 
-
 class HandlerMixin(object):
       
     def _response_generator(self, request):
@@ -108,10 +107,12 @@ After obtaining the result from the
 :meth:`Application.handle_event_task` method, it invokes the
 :meth:`Worker.end_task` method to close the request.'''
         self.nr += 1
-        should_stop = self.max_requests and self.nr >= self.max_requests        
+        request = self.app.request_instance(request)
+        timeout = getattr(request,'timeout',None)
+        should_stop = self.max_requests and self.nr >= self.max_requests 
         make_async(self._response_generator(request)).add_callback(
                lambda res : self.close_response(request,res,should_stop))\
-               .start(self.ioloop)
+               .start(self.ioloop, timeout = timeout)
         
     def close_response(self, request, response, should_stop):
         '''Close the response. This method should be called by the
@@ -150,6 +151,10 @@ used for by the application for handling requests and sending back responses.
 .. attribute:: cfg
 
     Configuration dictionary
+    
+.. attribute:: app_handler
+
+    The application handler obtained from :meth:`Application.handler`.
 
 """        
     def on_init(self, app = None, **kwargs):
@@ -162,6 +167,7 @@ used for by the application for handling requests and sending back responses.
     # Delegates Callbacks to the application
          
     def on_start(self):
+        #self.app.cfg.on_start()
         self.app.worker_start(self)
         try:
             self.cfg.worker_start(self)
@@ -183,10 +189,9 @@ used for by the application for handling requests and sending back responses.
         except:
             pass
         
-    def on_info(self, data):
-        data.update({'request processed': self.nr,
-                     'max requests':self.cfg.max_requests})
-        return data
+    def on_info(self, info):
+        info.update({'request processed': self.nr})
+        return self.app.on_info(self,info)
 
 
 class ApplicationMonitor(HandlerMixin,pulsar.Monitor):
@@ -234,6 +239,10 @@ pulsar applications (subclasses of :class:`Application`).
         
     def on_exit(self):
         self.app.monitor_exit(self)
+        try:
+            self.cfg.worker_exit(self)
+        except:
+            pass
     
     def clean_up(self):
         self.worker_class.clean_arbiter_loop(self,self.ioloop)
@@ -254,10 +263,10 @@ updated actor parameters with information about the application.
                  'impl': c,
                  'name':'{0}-worker'.format(app.name)}
         
-    def _info(self, result = None):
-        info = super(ApplicationMonitor,self)._info(result)
-        info.update({'default_timeout': self.cfg.timeout})
-        return info
+    def on_info(self, info):
+        info.update({'default_timeout': self.cfg.timeout,
+                     'max_requests': self.cfg.max_requests})
+        return self.app.on_info(self,info)
     
 
 class Application(pulsar.LogginMixin):
@@ -346,7 +355,7 @@ its duties.
             monitor = arbiter.add_monitor(self.monitor_class,
                                           self.name,
                                           app = self,
-                                          ioqueue = self.get_ioqueue())
+                                          ioqueue = self.ioqueue)
             self.mid = monitor.aid
             r,f = self.remote_functions()
             if r:
@@ -360,6 +369,23 @@ its duties.
         '''Application name, It is unique and defines the application.'''
         return self._name
     
+    @property
+    def ioqueue(self):
+        if 'queue' not in self.local:
+            self.local['queue'] = self.get_ioqueue()
+        return self.local['queue']
+    
+    def handler(self):
+        '''Returns the callable application handler which is stored in
+:attr:`Worker.app_handler`, used by :class:`Worker` to carry out its task.
+By default it returns the :attr:`Application.callable`.'''
+        return self.callable
+    
+    def request_instance(self, request):
+        '''Given a request raiosed from an event, build the request for the
+ :meth:`handle_request` method. By default it returns ``request``.'''
+        return request
+    
     def handle_message(self, sender, receiver, message):
         '''Handle messages for the *receiver*.'''
         handler = getattr(self,'actor_' + message.action,None)
@@ -387,6 +413,15 @@ will have a :class:`IOLoop` instance based on the queue (via :class:`IOQueue`).
 By default it returns ``None``.'''
         return None
     
+    def put(self, request):
+        queue = self.ioqueue
+        if queue:
+            self.log.debug('Put {0} on IO queue'.format(request))
+            queue.put(('request',request))
+        else:
+            self.log.error("Trying to put a request on task queue,\
+ but there isn't one!")
+    
     def on_config(self):
         '''Callback when configuration is loaded. This is a chance to do
  an application specific check before the concurrent machinery is put into
@@ -512,18 +547,14 @@ The parameters overrriding order is the following:
     def init(self, opts):
         pass
     
-    def handler(self):
-        '''Returns a callable application handler,
-used by a :class:`Worker` to carry out its task. By default it
-returns the :attr:`Application.callable`.'''
-        return self.callable
-    
     def monitor_handler(self):
         '''Returns a application handler for the monitor.
 By default it returns ``None``.'''
         return None
     
     # MONITOR AND WORKER CALLBACKS
+    def on_info(self, worker, data):
+        return data
     
     def update_worker_paramaters(self, monitor, params):
         '''Called by the :class:`ApplicationMonitor` when
