@@ -1,7 +1,11 @@
 '''\
 Asynchronous WSGI Remote Procedure Calls middleware. It implements a
-JSON-RPC_ server and client. To create a server first you create your
-rpc handler and (optional) subhandlers::
+JSON-RPC_ server and client.
+
+RPC server
+=====================
+To create a server first you create your rpc handler and
+(optional) subhandlers::
 
     from pulsar.apps import rpc, wsgi
     
@@ -21,12 +25,17 @@ rpc handler and (optional) subhandlers::
         
         def rpc_divide(self, request, a, b):
             return float(a) / float(b)
-            
-    
-    root = Root().putSubHandler('calc',Calculator())
-    wsgi.createServer(callable = root).start()
     
 
+Then you create the WSGI Middleware::
+
+    def server(**params):
+        root = Root().putSubHandler('calc',Calculator())
+        return wsgi.createServer(callable = rpc.RpcMiddleware(root), **params)
+    
+    if __name__ == '__main__':
+        server().start()
+    
 .. _JSON-RPC: http://en.wikipedia.org/wiki/JSON-RPC
 '''
 from .exceptions import *
