@@ -211,13 +211,16 @@ be scheduled. If so it makes the task requests.
 Check the :meth:`TaskQueue.monitor_task` callback
 for implementation.'''
         return self.local.get('scheduler')
-    
+        
     def get_ioqueue(self):
         '''Return the distributed task queue which produces tasks to
 be consumed by the workers.'''
         queue = self.cfg.task_queue_factory
         return queue()
     
+    def request_instance(self, request):
+        return self.task_class.from_queue(request)
+    
     def __init__(self, task_class = None, **kwargs):
         self.tasks_statistics = {'total':0,
                                  'failures':0}
