@@ -1,4 +1,6 @@
 from datetime import datetime, date
+from hashlib import sha1
+import logging
 import inspect
 
 from pulsar.utils.py2py3 import iteritems
@@ -7,18 +9,24 @@ from pulsar.utils.py2py3 import iteritems
 from pulsar.utils.tools import gen_unique_id
 
 
-__all__ = ['Job','PeriodicJob','anchorDate','registry']
+__all__ = ['JobMetaClass','Job','PeriodicJob',
+           'anchorDate','JobRegistry','registry',
+           'create_task_id']
+
+
+def create_task_id():
+    return gen_unique_id()[:8]
 
 
 class JobRegistry(dict):
     """Site registry for tasks."""
 
     def regular(self):
-        """A generator of all regular task types."""
+        """A generator of all regular jobs."""
         return self.filter_types("regular")
 
     def periodic(self):
-        """A generator of all periodic task types."""
+        """A generator of all periodic jobs."""
         return self.filter_types("periodic")
 
     def register(self, job):
@@ -44,14 +52,17 @@ registry = JobRegistry()
 
 
 class JobMetaClass(type):
-    """Metaclass for Jobs.
+    """Metaclass for Jobs. It performs a little ammount of magic
+by:
 
-    Automatically registers the Job in the Job registry, except
-    if the ``abstract`` attribute is set.
-
-    If no ``name`` attribute is provided, the name is automatically
-    set to the name of the module it was defined in, and the class name.
-    """
+* Automatic registration of :class:`Job` instances to the
+  global :class:`JobRegistry`, unless
+  the :attr:`Job.abstract` attribute is set to ``True``.
+* If no :attr:`Job.name`` attribute is provided,
+  it is automatically set to the class name in lower case.
+* Add a logger instance with name given by 'job.name` where name is the
+  same as above.
+"""
 
     def __new__(cls, name, bases, attrs):
         super_new = super(JobMetaClass, cls).__new__
@@ -65,13 +76,14 @@ class JobMetaClass(type):
 
         # Automatically generate missing name.
         job_name = attrs.get("name",name).lower()
-        attrs["name"] = job_name
 
         # Because of the way import happens (recursively)
         # we may or may not be the first time the Job tries to register
         # with the framework. There should only be one class for each Job
         # name, so we always return the registered version.
         if job_name not in registry:
+            attrs["name"] = job_name
+            attrs['logger'] = logging.getLogger('job.{0}'.format(name))
             job_cls = super_new(cls, name, bases, attrs)
             registry.register(job_cls)
         return registry[job_name].__class__
@@ -81,15 +93,52 @@ JobBase = JobMetaClass('JobBase',(object,),{'abstract':True})
 
 
 class Job(JobBase):
-    '''The Job class which is used in a distributed task queue.'''
+    '''The Job class which is used in a distributed task queue.
+    
+.. attribute:: name
+
+    The unique name which defines the Job and which can be used to retrieve
+    it from the job registry.
+    
+.. attribute:: abstract
+
+    If set to ``True`` (default is ``False``), the Job won't be registered
+    with the Job registry.
+    
+.. attribute:: autoregister
+
+    If ``False`` (default is ``True``), the Job need to be registered
+    manually with the Job registry.
+    
+.. attribute:: type
+
+    Type of Job, one of ``regular`` and ``periodic``.
+    
+.. attribute:: timeout
+
+    An instance of a datetime.timedelta or ``None``. If set, it represents the
+    time lag after which a task whch has not been processed expires.
+    
+    Default ``None``.
+    
+.. attribute:: can_overlap
+
+    Boolean indicating if this job can generate overlapping tasks with same
+    input parameters.
+    
+    Default ``True``.
+    
+.. attribute:: logger
+
+    an instance of a logger.
+'''
     abstract = True
-    '''If set to ``True`` (default is ``False``), the Job won't be registered with the Job registry.'''
     autoregister = True
-    '''If ``False`` (default is ``True``), the Job need to be registered manually with the Job registry.'''
     type = "regular"
-    '''Type of Job, one of ``regular`` and ``periodic``'''
     timeout = None
     expires = None
+    logformatter = None
+    can_overlap = True
     _ack = True
         
     def __call__(self, consumer, *args, **kwargs):
@@ -98,8 +147,27 @@ implemented by subclasses.'''
         raise NotImplementedError("Jobs must define the run method.")
     
     def make_task_id(self, args, kwargs):
-        '''Get the task unique identifier. This can be overridden by Job implementation.'''
-        return gen_unique_id()
+        '''Get the task unique identifier.
+This can be overridden by Job implementation.
+
+:parameter args: tuple of positional arguments passed to the job callable.
+:parameter kwargs: dictionary of key-valued parameters passed to
+    the job callable.
+:rtype: a native string.
+    
+Called by the :attr:`TaskQueue.scheduler` when creating a new task.
+'''
+        if self.can_overlap:
+            return create_task_id()
+        else:
+            suffix = ''
+            if args:
+                suffix = 'args(' + ', '.join((str(a) for a in args)) + ')'
+            if kwargs:
+                suffix += 'kwargs(' + ', '.join('{0}= {1}'.\
+                            format(k,kwargs[k]) for k in sorted(kwargs)) + ')'
+            name = self.name + suffix
+            return sha1(name.encode('utf-8')).hexdigest()[:8]
     
     def on_same_id(self, task):
         '''Callback invocked when a task has an id equal to a task already
@@ -143,6 +211,7 @@ where next time to run is in seconds. e.g.
 You can override this to decide the interval at runtime.
         """
         return self.run_every.is_due(last_run_at)
+    
 
 
 def anchorDate(hour = 0, minute = 0, second = 0):
