@@ -53,6 +53,7 @@ When running a test, pulsar looks for two extra method: ``_pre_setup`` and
 ``setUp`` method while if the latter is available, it is run
 just after the ``tearDown`` method.
 '''
+__test__ = False
 import unittest
 import logging
 import os
@@ -103,12 +104,9 @@ is a group of tests specified in a test class.
     plugins = ()
     config_options_include = ('timeout','concurrency','workers','loglevel',
                               'worker_class','debug','task_queue_factory',
-                              'http_proxy')
+                              'http_proxy','http_client','http_py_parser')
     default_logging_level = None
-    cfg = {'timeout':300,
-           #'concurrency':'thread',
-           'workers':1,
-           'loglevel':'none'}
+    cfg = {'workers':1, 'loglevel':'none'}
     
     def handler(self):
         return self
@@ -151,8 +149,8 @@ configuration and plugins.'''
         runner = self.runner
         
         if not modules:
-            raise ValueError('No modules specified. Please pass the modules\
- parameters to the TestSuite Constructor.')
+            modules = ((None,'tests'),)
+
         if hasattr(modules,'__call__'):
             modules = modules(self)
             
@@ -190,8 +188,8 @@ configuration and plugins.'''
             self.runner.on_start()
             monitor.cfg.set('workers',min(self.cfg.workers,len(tests)))
             self._time_start = time.time()
-            for _,testcls in tests:
-                monitor.put(TestRequest(testcls))
+            for tag,testcls in tests:
+                monitor.put(TestRequest(testcls,tag))
         else:
             print('Could not find any tests.')
             monitor.arbiter.stop()
