@@ -193,8 +193,10 @@ class SafeAsync(object):
         
         
 def async_pair(val, max_errors = None):
-    '''Convert val into an asynchronous pair or a function returning an
-asynchronous pair.
+    '''Convert *val* into an asynchronous pair or a function returning an
+asynchronous pair wich is a two element tuple with the first element being
+an asynchronous representation of *val* and the second a :class:`Deferred`
+which is called back once *val* is ready.
 
 :parameter val: A function or an object.
 :parameter max_errors: maximum number of errors allowed.
@@ -234,14 +236,22 @@ result as argument. Raise exceptions if result is one.'''
 
 
 class Deferred(object):
-    """This is a callback which will be put off until later. The idea is the same
-as the ``twisted.defer.Deferred`` object.
+    """This is a callback which will be put off until later.
+The idea is the same as the ``twisted.defer.Deferred`` object.
 
 Use this class to return from functions which otherwise would block the
-program execution. Instead, it should return a Deferred."""
+program execution. Instead, it should return a Deferred.
+
+.. attribute:: called
+
+    ``True`` if the deferred was called. In this case the asynchronous result
+    is ready and available in the attr:`result`.
+    
+"""
     def __init__(self, rid = None, description = None):
         self._called = False
         self._description = description
+        self._runningCallbacks = False
         self.paused = 0
         self.rid = rid
         self._ioloop = None
@@ -251,8 +261,7 @@ program execution. Instead, it should return a Deferred."""
         pass
     
     def __repr__(self):
-        d = self._description or ''
-        return d
+        return self._description or self.__class__.__name__
     
     def __str__(self):
         return self. __repr__()            
@@ -267,48 +276,52 @@ program execution. Instead, it should return a Deferred."""
         self.paused += 1
 
     def unpause(self):
-        """
-        Process all callbacks made since L{pause}() was called.
+        """Process all callbacks made since :meth:`pause` was called.
         """
         self.paused -= 1
-        if self.paused:
-            return
-        if self.called:
-            self._run_callbacks()
+        self._run_callbacks()
     
-    def add_callback(self, callback):
+    def add_callback(self, callback, raise_on_error = False):
         """Add a callback as a callable function.
 The function takes at most one argument, the result passed to the
 :meth:`callback` method."""
         if hasattr(callback,'__call__'):
             self._callbacks.append(callback)
+            if raise_on_error:
+                self._callbacks.append(raise_failure)
             self._run_callbacks()
         return self
         
     def _run_callbacks(self):
-        if self._called and self._callbacks:
-            callbacks = self._callbacks
-            while callbacks:
-                if isinstance(self.result,Failure):
-                    if self.result.should_stop:
-                        rasult.raise_all()
-                callback = callbacks.pop(0)
-                try:
-                    self._runningCallbacks = True
-                    try:
-                        self.result = callback(self.result)
-                    finally:
-                        self._runningCallbacks = False
-                    if isinstance(self.result, Deferred):
-                        # Add a pause and add new callback
-                        self.pause()
-                        self.result.add_callback(self._continue)
-                except:
-                    self.result = update_failure(self.result)
-                
+        if not self.called or self._runningCallbacks:
+            return
+        
+        if self.paused:
+            return
+        
+        while self._callbacks:
             if isinstance(self.result,Failure):
                 if self.result.should_stop:
                     self.result.raise_all()
+            callback = self._callbacks.pop(0)
+            try:
+                self._runningCallbacks = True
+                try:
+                    self.result = callback(self.result)
+                finally:
+                    self._runningCallbacks = False
+                if isinstance(self.result, Deferred):
+                    # Add a pause
+                    self.pause()
+                    # Add a callback to the result to resume callbacks
+                    self.result.add_callback(self._continue)
+                    break
+            except:
+                self.result = update_failure(self.result)
+            
+        if isinstance(self.result,Failure):
+            if self.result.should_stop:
+                self.result.raise_all()
     
     def add_callback_args(self, callback, *args, **kwargs):
         return self.add_callback(\
@@ -317,6 +330,7 @@ The function takes at most one argument, the result passed to the
     def _continue(self, result):
         self.result = result
         self.unpause()
+        return self.result
     
     def callback(self, result = None):
         '''Run registered callbacks with the given *result*.
@@ -351,13 +365,17 @@ ready it throws a :class:`DeferredFailure` exception'''
                 raise DeferredFailure('Deferred not called')
         return self.result
 
-    def start(self, ioloop, timeout = None):
+    def start(self, ioloop, timeout = 5):
         '''Start running the deferred into an Event loop.
 If the deferred was already started do nothing.
 
 :parameter ioloop: :class:`IOLoop` instance where to run the deferred.
-:parameter timeout: Optional timeout in seconds. If the deferred has not done within
-    this time period it will raise a :class:`Timeout` exception.
+:parameter timeout: Optional timeout in seconds. If the deferred has not
+    been called within this time period it will raise a :class:`Timeout`
+    exception and it won't add itself to the callbacks.
+    
+    Default: 5
+    
 :rtype: ``self``.
 
 A common usage pattern::
@@ -387,8 +405,8 @@ in :meth:`start`.'''
         if not self.called:
             try:
                 if self._timeout and time() - self._started > self._timeout:
-                    raise Timeout('Timeout {0} reached without results.\
- Aborting.'.format(self._timeout))
+                    raise Timeout('Deferred "{0}" not called.'.format(self),
+                                  self._timeout)
                 self._ioloop.add_callback(self._consume)
             except:
                 self.callback(sys.exc_info())
