@@ -6,7 +6,6 @@ from pulsar.utils.tools import gen_unique_id
 from pulsar.utils.py2py3 import pickle
 
 from .iostream import AsyncIOStream
-from .mailbox import mailbox, IOQueue, SocketServerMailbox
 from .proxy import ActorProxyMonitor
 
 
@@ -47,8 +46,6 @@ and are shared between the :class:`Actor` and its
         self.loglevel = kwargs.pop('loglevel',None)
         self.remotes = actor_class.remotes
         self.a_kwargs = kwargs
-        self.inbox = self.get_inbox(arbiter,kwargs.get('monitor'))
-        self.outbox = None
         self.process_actor(arbiter)
        
     @property
@@ -63,36 +60,10 @@ and are shared between the :class:`Actor` and its
     
     def process_actor(self, arbiter):
         '''Called at initialization, it set up communication layers for the
-actor. In particular here is where the inbox and outbox handlers are created.
-The outbox is either based on a socket or a pipe, while the inbox could be
-a socket, a pipe or a queue.'''
-        kwargs = self.a_kwargs
-        monitor = kwargs.pop('monitor',None)
-        if arbiter.inbox:
-            self.outbox = mailbox(address = arbiter.inbox.address())
-        if monitor:
-            monitor = monitor.proxy
-        kwargs.update({'arbiter':arbiter.proxy,
-                       'monitor':monitor})
-        
-    def get_inbox(self, arbiter, monitor):
-        '''Create the inbox :class:`Mailbox`.
-
-:parameter arbiter: The :class:`Arbiter`
-:parameter monitor: Optional instance of the :class:`Monitor` supervising
-    the actor.
-:rtype: an instance of :class:`Mailbox`
-
-If a monitor is available, check if it has a task queue.
-If so the mailbox will be based on the queue since the actor
-won't have a select/epoll type ionput/output but one based on
-:class:`IOQueue`.
-'''
-        ioq = self.a_kwargs.get('ioqueue')
-        if ioq:
-            return mailbox(id = 'inbox', queue = ioq)
-        else:
-            return SocketServerMailbox()
+actor. In particular here is where the outbox handler is created.'''
+        monitor = self.a_kwargs.pop('monitor',None)
+        self.a_kwargs.update({'arbiter':arbiter.proxy,
+                              'monitor':monitor.proxy if monitor else None})
         
     def make_actor(self):
         '''create an instance of :class:`Actor`. For standard actors, this
@@ -112,11 +83,6 @@ loop and therefore do not require an inbox.'''
         self.timeout = 0
         self.make_actor()
         
-    def get_inbox(self, arbiter, monitor):
-        if not arbiter:
-            # This is the arbiter implementation
-            return SocketServerMailbox()
-        
     def proxy_monitor(self):
         return None
     
