@@ -4,6 +4,7 @@ import logging
 import socket
 import errno
 from collections import deque
+from threading import current_thread
 
 from .defer import Deferred, is_async
 
@@ -17,7 +18,7 @@ def make_callback(callback, description = None):
     if is_async(callback):
         return callback
     d = Deferred(description = description)
-    return d.add_callback(callback)
+    return d.add_callback(callback, True)
 
 
 class IOStream(object):
@@ -41,9 +42,7 @@ manipulated and adapted to pulsar :ref:`concurrent framework <design>`.
                  **kwargs):
         self.socket = socket
         self.socket.setblocking(self.blocking())
-        #self.MAX_BODY = 1024 * 128
-        # So we can send chunked with  Transfer-Encoding
-        self.MAX_BODY = 1024 * 127
+        self.MAX_BODY = 1024 * 128
         self.max_buffer_size = max_buffer_size or 104857600
         self.read_chunk_size = read_chunk_size or io.DEFAULT_BUFFER_SIZE
         self._read_buffer = deque()
@@ -85,7 +84,7 @@ manipulated and adapted to pulsar :ref:`concurrent framework <design>`.
             self.ioloop = actor.ioloop
         else:
             self.log = iologger
-            self.ioloop = None
+            self.ioloop = getattr(current_thread(),'ioloop',None)
         
     def blocking(self):
         '''Boolean indication if the socket is blocking.'''
@@ -302,21 +301,9 @@ On error closes the socket and raises an exception."""
                     # with more than 128KB at a time.
                     buff = self._get_buffer(self._write_buffer, self.MAX_BODY)
                 else:
-                    buff = self._write_buffer.popleft() or b'' 
-                num_bytes = self.socket.send(buff)
-                if num_bytes == 0:
-                    # With OpenSSL, if we couldn't write the entire buffer,
-                    # the very same string object must be used on the
-                    # next call to send.  Therefore we suppress
-                    # merging the write buffer after an incomplete send.
-                    # A cleaner solution would be to set
-                    # SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER, but this is
-                    # not yet accessible from python
-                    # (http://bugs.python.org/issue8240)
-                    self._write_buffer.appendleft(buff)
-                    self._write_buffer_frozen = True
-                    break
-                self._write_buffer_frozen = False
+                    buff = self._write_buffer.popleft() or b''
+                num_bytes = len(buff)
+                self.socket.sendall(buff)
                 tot_bytes += num_bytes
             except socket.error as e:
                 if e.args[0] in (errno.EWOULDBLOCK, errno.EAGAIN):
@@ -398,15 +385,17 @@ read from a non-blocking socket.
         but is non-portable.
         """
         self._connecting = True
+        d = make_callback(callback,
+                  description = '{0} Connect callback'.format(self))
+        self._connect_callback = d.callback
         try:
             self.socket.connect(address)
         except socket.error as e:
             # In non-blocking mode connect() always raises an exception
             if e.args[0] not in (errno.EINPROGRESS, errno.EWOULDBLOCK):
                 raise
-        
-        self._connect_callback = self.wrap(callback)
         self._add_io_state(self.ioloop.WRITE)
+        return d
 
     def set_close_callback(self, callback):
         """Call the given callback when the stream is closed."""
